==> pinn-0.1.0.tar.gz: pinn-0.1.0/README.md <==
![Pinn Python Library](https://github.com/pinntech/pinn-python/raw/master/docs/_static/pinn-python-logo.png)
---

[![PyPI version shields.io](https://img.shields.io/pypi/v/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI license](https://img.shields.io/pypi/l/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI status](https://img.shields.io/pypi/status/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![Documentation Status](https://readthedocs.org/projects/pinn/badge/?version=latest)](http://pinn.readthedocs.io/?badge=latest)
[![Build Status](https://travis-ci.com/pinntech/pinn-python.svg?branch=master)](https://travis-ci.com/pinntech/pinn-python)


The Pinn Python library is the easiest, fastest and most enjoyable way to integrate
Pinn into your existing or new python project. This interface around our REST API
provides an idiomatic, ORM-style usage that will make life easy.

## Table of Contents
* [Installation](#installation)
* [Documentation](#documentation)
* [Usage](#usage)
* [Changelog](#changelog)
* [License](#license)

## Installation

The easiest way to get started is:
```shell
pip install --upgrade pinn
```

Alternatively you could also install directly from source like so:
```shell
python setup.py install
```

## Documentation

For a full run down of the library please see the reference documentation [here](google.com), or keep reading on for just the basics.

## Usage

This section details some of the most essential API actions and how to perform them using
this library.

## Changelog

For a detailed account of each release, please refer to the [CHANGELOG](CHANGELOG.md).

## License

Copyright (c) 2019 Pinn Technologies, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> pinn-0.1.2.tar.gz: pinn-0.1.2/README.md <==
![Pinn Python Library](https://github.com/pinntech/pinn-python/raw/master/docs/_static/pinn-python-logo.png)
---

[![PyPI version shields.io](https://img.shields.io/pypi/v/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI license](https://img.shields.io/pypi/l/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![PyPI status](https://img.shields.io/pypi/status/pinn.svg)](https://pypi.python.org/pypi/pinn/)
[![Documentation Status](https://readthedocs.org/projects/pinn/badge/?version=latest)](http://pinn.readthedocs.io/?badge=latest)
[![Build Status](https://travis-ci.com/pinntech/pinn-python.svg?branch=master)](https://travis-ci.com/pinntech/pinn-python)


The Pinn Python library is the easiest, fastest and most enjoyable way to integrate
Pinn into your existing or new python project. This interface around our REST API
provides an idiomatic, ORM-style usage that will make life easy.

## Table of Contents
* [Installation](#installation)
* [Documentation](#documentation)
* [Usage](#usage)
* [Changelog](#changelog)
* [License](#license)

## Installation

The easiest way to get started is:
```shell
pip install --upgrade pinn
```

Alternatively you could also install directly from source like so:
```shell
python setup.py install
```

## Documentation

For a full run down of the library please see the reference documentation [here](https://pinn.readthedocs.io), or keep reading on for just the basics.

## Usage

This section details some of the most essential API actions and how to perform them using
this library.

## Changelog

For a detailed account of each release, please refer to the [CHANGELOG](CHANGELOG.md).

## License

Copyright (c) 2019 Pinn Technologies, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
